module SuperLogger
  def self.conf
    SuperLogger.config
  end

  def self.base_line
    @line ||= conf.rule_character * conf.line_length
  end

  def self.log(loggable, key = nil, log_level = 'info')
    horizontal_rule(log_level, key)

    MessageFormatter.format(loggable).each do |message|
      actual_log message, log_level
    end

    horizontal_rule(log_level)
  end

  def self.actual_log(message, log_level)
    conf.logger.send(log_level, message)
  end

  def self.rule_with_text(key)
    computed_length = base_line.length - (key.length + 2)
    partial_line = conf.rule_character * (computed_length / 2).floor

    "#{partial_line} #{key} #{partial_line}"
  end

  def self.horizontal_rule(log_level, key = nil)
    middle_line = key ? rule_with_text(key) : base_line

    actual_log(base_line, log_level)
    actual_log(middle_line, log_level)
    actual_log(base_line, log_level)
    actual_log(String.new, log_level) unless key
  end
end
